@@ -716,6 +716,39 @@ def get_wake(
 
         return wake_command
 
+    if wake_system == "raven":
+        wake_command = ["rhasspy-wake-raven-hermes"]
+
+        template_dir = profile.get("wake.raven.template_dir")
+        if template_dir:
+            wake_command.extend(
+                ["--template-dir", shlex.quote(str(write_path(profile, template_dir)))]
+            )
+
+        probability_threshold = profile.get("wake.raven.probability_threshold")
+        if probability_threshold:
+            wake_command.extend(["--probability-threshold", str(probability_threshold)])
+
+        minimum_matches = profile.get("wake.raven.minimum_matches")
+        if minimum_matches:
+            wake_command.extend(["--minimum-matches", str(minimum_matches)])
+
+        add_standard_args(
+            profile,
+            wake_command,
+            site_ids,
+            mqtt_host,
+            mqtt_port,
+            mqtt_username,
+            mqtt_password,
+        )
+
+        udp_audio = profile.get("wake.raven.udp_audio", "")
+        if udp_audio:
+            add_udp_audio_settings(wake_command, udp_audio, wake_site_id)
+
+        return wake_command
+
     if wake_system == "command":
         user_program = profile.get("wake.command.program")
         if not user_program:
@@ -2153,6 +2186,53 @@ def get_text_to_speech(
 
         return tts_command
 
+    if tts_system == "wavenet":
+
+        voice = str(profile.get("text_to_speech.wavenet.voice", "Wavenet-C")).strip()
+        gender = str(profile.get("text_to_speech.wavenet.gender", "FEMALE")).strip()
+        sample_rate = str(profile.get("text_to_speech.wavenet.sample_rate", 22050))
+        language_code = str(
+            profile.get("text_to_speech.wavenet.language_code", "en-US")
+        ).strip()
+
+        credentials_json = profile.get("text_to_speech.wavenet.credentials_json")
+        if not credentials_json:
+            _LOGGER.error("text_to_speech.wavenet.credentials_json required")
+            return []
+
+        cache_dir = profile.get("text_to_speech.wavenet.cache_dir")
+        if not cache_dir:
+            _LOGGER.error("text_to_speech.wavenet.cache_dir is required")
+            return []
+
+        tts_command = [
+            "rhasspy-tts-wavenet-hermes",
+            "--credentials-json",
+            shlex.quote(str(write_path(profile, credentials_json))),
+            "--cache-dir",
+            shlex.quote(str(write_path(profile, cache_dir))),
+            "--voice",
+            shlex.quote(voice),
+            "--gender",
+            shlex.quote(gender),
+            "--sample-rate",
+            shlex.quote(sample_rate),
+            "--language-code",
+            shlex.quote(language_code),
+        ]
+
+        add_standard_args(
+            profile,
+            tts_command,
+            site_ids,
+            mqtt_host,
+            mqtt_port,
+            mqtt_username,
+            mqtt_password,
+        )
+
+        return tts_command
+
     if tts_system == "opentts":
         url = profile.get("text_to_speech.opentts.url", "").strip()
         if not url:
